Index: trunk/SophyaLib/NTools/generalfit.cc
===================================================================
--- trunk/SophyaLib/NTools/generalfit.cc	(revision 508)
+++ trunk/SophyaLib/NTools/generalfit.cc	(revision 514)
@@ -9,9 +9,6 @@
 #include "pexceptions.h"
 #include "generalfit.h"
-#include "cvector.h"
 
 #define EPS_FIT_MIN 1.e-8
-
-using namespace PlanckDPC;
 
 //================================================================
@@ -874,5 +871,5 @@
 
 //++
-OVector GeneralFit::GetParm()
+Vector GeneralFit::GetParm()
 //
 //	Retourne les valeurs des parametres dans un vecteur.
@@ -1096,11 +1093,11 @@
 {
  volatile double oldChi2;
- OMatrix COVAR(mNPar,mNPar);
- OVector DA(mNPar);
- OVector dparam(mNPar);
- OVector paramTry(mNPar);
- OVector param_tr(mNPar);
- OVector paramTry_tr(mNPar);
- OVector step_tr(mNPar);
+ Matrix COVAR(mNPar,mNPar);
+ Vector DA(mNPar);
+ Vector dparam(mNPar);
+ Vector paramTry(mNPar);
+ Vector param_tr(mNPar);
+ Vector paramTry_tr(mNPar);
+ Vector step_tr(mNPar);
  nStop = nStopL = nStep = 0;
  Chi2 = oldChi2 = 0.;
@@ -1515,5 +1512,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::write_in_step(double ci2,OVector& par)
+void GeneralFit::write_in_step(double ci2,Vector& par)
 {
 if(FileStep==NULL) return;
@@ -1524,11 +1521,11 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::TryFunc(OVector& par,OVector& par_tr)
+void GeneralFit::TryFunc(Vector& par,Vector& par_tr)
 {
   BETA_Try = 0;
   ATGA_Try = 0;
   Chi2  = 0;
-  OVector deriv(mNPar);
-  OVector derivtr(mNPar);
+  Vector deriv(mNPar);
+  Vector derivtr(mNPar);
   double result;
 
@@ -1564,5 +1561,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::TryXi2(OVector& par,OVector& par_tr)
+void GeneralFit::TryXi2(Vector& par,Vector& par_tr)
 {
   double c, *parloc;
@@ -1664,7 +1661,7 @@
 
 //////////////////////////////////////////////////////////////////////
-OVector GeneralFit::p_vers_tr(OVector const& p)
-{
- OVector tr(p);
+Vector GeneralFit::p_vers_tr(Vector const& p)
+{
+ Vector tr(p);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1675,5 +1672,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::p_vers_tr(OVector const& p,OVector& tr)
+void GeneralFit::p_vers_tr(Vector const& p,Vector& tr)
 {
  for(int i=0;i<mNPar;i++) {
@@ -1695,7 +1692,7 @@
 
 //////////////////////////////////////////////////////////////////////
-OVector GeneralFit::tr_vers_p(OVector const& tr)
-{
- OVector p(tr);
+Vector GeneralFit::tr_vers_p(Vector const& tr)
+{
+ Vector p(tr);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1706,5 +1703,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::tr_vers_p(OVector const& tr,OVector& p)
+void GeneralFit::tr_vers_p(Vector const& tr,Vector& p)
 {
  for(int i=0;i<mNPar;i++) {
@@ -1727,7 +1724,7 @@
 
 //////////////////////////////////////////////////////////////////////
-OVector GeneralFit::dp_vers_dtr(OVector const& dp,OVector const& tr)
-{
- OVector dtr(dp);
+Vector GeneralFit::dp_vers_dtr(Vector const& dp,Vector const& tr)
+{
+ Vector dtr(dp);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1738,5 +1735,5 @@
 
 //////////////////////////////////////////////////////////////////////
-void GeneralFit::dp_vers_dtr(OVector const& dp,OVector const& tr,OVector& dtr)
+void GeneralFit::dp_vers_dtr(Vector const& dp,Vector const& tr,Vector& dtr)
 {
  for(int i=0;i<mNPar;i++) {
@@ -1759,7 +1756,7 @@
 
 //////////////////////////////////////////////////////////////////////
-OVector GeneralFit::dtr_vers_dp(OVector const& dtr,OVector const& tr)
-{
- OVector dp(dtr);
+Vector GeneralFit::dtr_vers_dp(Vector const& dtr,Vector const& tr)
+{
+ Vector dp(dtr);
  for(int i=0;i<mNPar;i++) {
    if( fixParam[i] || ! boundParam[i] ) continue;
@@ -1771,8 +1768,8 @@
 //////////////////////////////////////////////////////////////////////
 // inline fonction pour aller + vite dans le try()
-//void GeneralFit::dtr_vers_dp(OVector const& dtr,OVector const& tr,OVector& dp)
-
-//////////////////////////////////////////////////////////////////////
-int GeneralFit::put_in_limits_for_deriv(OVector const& p,OVector& dp,double dist)
+//void GeneralFit::dtr_vers_dp(Vector const& dtr,Vector const& tr,Vector& dp)
+
+//////////////////////////////////////////////////////////////////////
+int GeneralFit::put_in_limits_for_deriv(Vector const& p,Vector& dp,double dist)
 // 1-/ Redefinit dp pour qu'il soit superieur a minStepDeriv
 // 2-/ Redefinit dp pour que p+/-dp reste dans les limites (parametre borne)
